@@ -1,5 +1,3 @@
-import '../annotations_srv';
-import 'app/features/dashboard/time_srv';
 import { AnnotationsSrv } from '../annotations_srv';
 
 describe('AnnotationsSrv', () => {
@@ -23,7 +21,7 @@ describe('AnnotationsSrv', () => {
 
     const time = 1507039543000;
     const annotations = [{ id: 1, panelId: 1, text: 'text', time: time }];
-    let translatedAnnotations;
+    let translatedAnnotations: any;
 
     beforeEach(() => {
       translatedAnnotations = annotationsSrv.translateQueryResult(annotationSource, annotations);
