@@ -12,7 +12,10 @@ import { UsersState, UserState } from './user';
 import { OrganizationState } from './organization';
 import { AppNotificationsState } from './appNotifications';
 import { PluginsState } from './plugins';
-import { NavIndex } from '@grafana/ui';
+import { NavIndex } from '@grafana/data';
+import { ApplicationState } from './application';
+import { LdapState, LdapUserState } from './ldap';
+import { PanelEditorState } from '../features/dashboard/panel_editor/state/reducers';
 
 export interface StoreState {
   navIndex: NavIndex;
@@ -22,6 +25,7 @@ export interface StoreState {
   team: TeamState;
   folder: FolderState;
   dashboard: DashboardState;
+  panelEditor: PanelEditorState;
   dataSources: DataSourcesState;
   explore: ExploreState;
   users: UsersState;
@@ -29,6 +33,9 @@ export interface StoreState {
   appNotifications: AppNotificationsState;
   user: UserState;
   plugins: PluginsState;
+  application: ApplicationState;
+  ldap: LdapState;
+  ldapUser: LdapUserState;
 }
 
 /*
